package io.github.rmuhamedgaliev.service.HDD;

import java.io.File;
import java.nio.file.Path;
import java.util.List;

/**
 * Developer: Rinat Muhamedgaliev
 * Date: 07.03.13
 */
public interface HDDService
{
    /**
     * Return list path for files and directories recursive
     * @param path
     * @return
     */
    List<Path> getListPathInDirectory(Path path);

    /**
     * Get root path
     * @return
     */
    List<File> getRootPathForLinux();

    /**
     * Get total size partition
     * GiB - in gigabyte
     * MiB - in megabyte
     * KiB - in kilobyte
     * @param partition
     * @return value partition size
     */
    Long getTotalSizePartition(File partition, String measure);

    /**
     * Get free size partition
     * GiB - in gigabyte
     * MiB - in megabyte
     * KiB - in kilobyte
     * @param partition
     * @return value partition size
     */
    Long getFreeSizePartition(File partition, String measure);

    /**
     * Get used size partition
     * GiB - in gigabyte
     * MiB - in megabyte
     * KiB - in kilobyte
     * @param partition
     * @return value partition size
     */
    Long getUsedSizePartition(File partition, String measure);

    /**
     * Return mounded partition. Parsed standart 'df' command.
     * @return
     */
    List<File> getMountedDisks();
}
